@@ -80,9 +80,17 @@ class WebTest(TestCase):
 
     def assertUnauthorized(self, response, challenge=None):
         """
-        Assert that ``response`` was 401 Not Found.
+        Assert that ``response`` was 401 Unauthorized.
+
+        :param challenge: assert that the ``WWW-Authenticate`` header matches this value, if provided
         """
         self.assertEqual(401, response.status_int)
         if challenge:
             self.assertEqual(challenge, response.headers['WWW-Authenticate'])
+
+    def assertBadRequest(self, response):
+        """
+        Assert that ``response`` was 400 Bad Request.
+        """
+        self.assertEqual(400, response.status_int)
         
